@@ -1,15 +1,16 @@
 package Test::Mocha::Spy;
 # ABSTRACT: Spy objects
-$Test::Mocha::Spy::VERSION = '0.62';
+$Test::Mocha::Spy::VERSION = '0.63';
 use parent 'Test::Mocha::SpyBase';
 use strict;
 use warnings;
 
-use Carp 1.22 'croak';
-use Scalar::Util 'blessed';
+use Carp 1.22 ();
+use Scalar::Util ();
 use Test::Mocha::MethodCall;
-use Test::Mocha::Util qw( check_slurpy_arg extract_method_name find_caller );
-use Types::Standard 'Str';
+use Test::Mocha::MethodStub;
+use Test::Mocha::Util ();
+use Types::Standard   ();
 use UNIVERSAL::ref;
 
 our $AUTOLOAD;
@@ -18,7 +19,7 @@ my %DEFAULT_STUBS = (
     can => Test::Mocha::MethodStub->new(
         # can() should return a reference to AUTOLOAD() for all methods
         name      => 'can',
-        args      => [Str],
+        args      => [Types::Standard::Str],
         responses => [
             sub {
                 my ( $self, $method_name ) = @_;
@@ -48,7 +49,8 @@ my %DEFAULT_STUBS = (
 sub __new {
     # uncoverable pod
     my ( $class, $object ) = @_;
-    croak "Can't spy on an unblessed reference" if !blessed $object;
+    Carp::croak "Can't spy on an unblessed reference"
+      if !Scalar::Util::blessed($object);
 
     my $args = $class->SUPER::__new;
 
@@ -67,16 +69,16 @@ sub __object {
 
 sub AUTOLOAD {
     my ( $self, @args ) = @_;
-    check_slurpy_arg(@args);
+    Test::Mocha::Util::check_slurpy_arg(@args);
 
-    my $method_name = extract_method_name($AUTOLOAD);
+    my $method_name = Test::Mocha::Util::extract_method_name($AUTOLOAD);
 
     # record the method call for verification
     my $method_call = Test::Mocha::MethodCall->new(
         invocant => $self,
         name     => $method_name,
         args     => \@args,
-        caller   => [find_caller],
+        caller   => [Test::Mocha::Util::find_caller],
     );
 
     if ( $self->__CaptureMode ) {
@@ -86,15 +88,14 @@ sub AUTOLOAD {
             && $method_name ne 'ref'
           )
         {
-            croak(
+            Carp::croak(
                 sprintf
                   qq{Can't %s object method "%s" because it can't be located via package "%s"},
                 $self->__CaptureMode, $method_name, ref( $self->__object )
             );
         }
 
-        $self->__NumMethodCalls( $self->__NumMethodCalls + 1 );
-        $self->__LastMethodCall($method_call);
+        $self->__CaptureMethodCall($method_call);
         return;
     }
 
@@ -107,7 +108,7 @@ sub AUTOLOAD {
     }
 
     # delegate the method call to the real object
-    croak(
+    Carp::croak(
         sprintf
           qq{Can't call object method "%s" because it can't be located via package "%s"},
         $method_name,
@@ -147,7 +148,7 @@ sub can {
     my ( $self, $method_name ) = @_;
 
     # Handle can('CARP_TRACE') for internal croak()'s (Carp v1.32+)
-    #return if $method_name eq 'CARP_TRACE';
+    return if $method_name eq 'CARP_TRACE';
 
     $AUTOLOAD = 'can';
     goto &AUTOLOAD;
